@@ -5,7 +5,9 @@ from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag
 
 class LastIGContainsTagAttribute(BinaryAttribute):
 
-    def __init__(self, parse: MorphologicalParse, tag: MorphologicalTag):
+    def __init__(self,
+                 parse: MorphologicalParse,
+                 tag: MorphologicalTag):
         """
         Binary attribute for a given word. If the last inflectional group of the word contains tag,
         the attribute will be "true", otherwise "false".
